rm(list=ls(all=TRUE))

library(tidyverse)
library(pwr)
library(estimatr)
library(stargazer)
library(xtable)
library(effsize)

# set working directory
# setwd("~/Dropbox/Yale/VoterVoting/Shared_2016VoterVoting/BPP_replication/")

##================================##
## Read in data
##================================##

d <- read.csv("data.csv", header = TRUE, stringsAsFactors = FALSE, strip.white = TRUE)

states <- names(table(d$state))
comp <- names(table(d$competitive))

##================================##
## Helper functions
##================================##

## Extract p-values from one-tailed tests
otp <- function(fit, variable){
  s <- summary(fit)
  pt(coef(s)[,3], s$df[2], lower=FALSE)[variable]
}

## Make three part table using output from stargazer (float=FALSE)
make3ptable <- function(texinput, caption, label, resizebox, notes) {
  out <- c("\\begin{table}[!ht]",
           "\\centering",
           paste0("\\caption{",caption,"}"),
           paste0("\\label{",label,"}"),
           paste0("\\resizebox{",resizebox,"\\textwidth}{!}{"),
           "\\begin{threeparttable}",
           texinput,
           "\\begin{tablenotes}",
           "\\item $^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01, two-tailed t-tests unless otherwise specified.",
           paste0("\\item ", notes),
           "\\end{tablenotes}",
           "\\end{threeparttable}",
           "}",
           "\\end{table}"
  )
  return(out)
}

##================================##
## Table 2: Regression Analysis
##          for Pooled Sample
##================================##

# Define main model specifications

main_spec <- "vote_16g ~ treat_noun + treat_verb"  # PLACEBO IS OMITTED CATEGORY
vref_spec <- "vote_16g ~ placebo + treat_noun"     # VERB IS OMITTED CATEGORY
covs <- "age + agesq + female + race + educ + pid7 + ideo5 + day + vote_16p + vote_16pp + state"
covs_nostate <- "age + agesq + female + race + educ + pid7 + ideo5 + day + vote_16p + vote_16pp"
main_spec_adj <- paste(main_spec, covs, sep=" + ")
vref_spec_adj <- paste(vref_spec, covs, sep= "+ ")
main_spec_adj_nostate <- paste(main_spec, covs_nostate, sep=" + ")
vref_spec_adj_nostate <- paste(vref_spec, covs_nostate, sep= "+ ")

# Estimate models (omitted category: placebo)

fit_all <- list(lm(formula = as.formula(main_spec), data = d),
                lm(formula = as.formula(main_spec_adj), data = d))

# Estimate models (omitted category: verb) -- to get Noun-Verb difference

fit_vref <- list(lm(formula = as.formula(vref_spec), data = d),
                 lm(formula = as.formula(vref_spec_adj), data = d))

diff_nv <- lapply(fit_vref, function(J){
  x <- tidy(J)
  x <- x[x$term == 'treat_noun', c('estimate', 'std.error')]
  return(x)
})

diff_nv <- do.call(bind_rows, diff_nv)

diff_nv_est <- sprintf("%0.3f", round(unlist(diff_nv[,1]), 3))

diff_nv_se <- sprintf("%0.3f", round(unlist(diff_nv[,2]), 3))
diff_nv_se <- paste0("(", diff_nv_se, ")")

# One-sided tests

# Noun - Verb
otp_nv <- unlist(lapply(fit_vref, function(J) otp(J, "treat_noun")))
# Noun - Placebo
otp_np <- unlist(lapply(fit_all, function(J) otp(J, "treat_noun")))
# Verb - Placebo
otp_vp <- unlist(lapply(fit_all, function(J) otp(J, "treat_verb")))

otp_nv <- sprintf("%0.3f", round(otp_nv, 3))
otp_np <- sprintf("%0.3f", round(otp_np, 3))
otp_vp <- sprintf("%0.3f", round(otp_vp, 3))
  
# Format and output table
  
table3_tex <- stargazer(fit_all,
                        keep = c("treat", "Constant"),
                        covariate.labels = c("Voter (Noun) Treatment (1=Yes, 0=No)",
                                             "Voting (Verb) Treatment (1=Yes, 0=No)",
                                             "Constant"),
                        dep.var.caption = "",
                        dep.var.labels.include = FALSE,
                        keep.stat = c("n"),
                        add.lines = list(c("Difference: Noun-Verb", diff_nv_est),
                                         c("Difference: (SE)", diff_nv_se),
                                         c("p-value, one-tailed t-test, $H_0$: Noun-Verb=0; $H_A$: Noun-Verb>0", otp_nv),
                                         c("p-value, one-tailed t-test, $H_0$: Noun-Placebo=0; $H_A$: Noun-Placebo>0", otp_np),
                                         c("p-value, one-tailed t-test, $H_0$: Verb-Placebo=0; $H_A$: Verb-Placebo>0", otp_vp),
                                         c("With covariates?", "No", "Yes")),
                        omit.table.layout = "n",
                        float = FALSE)
  
table3_tex <- make3ptable(texinput = table3_tex,
                          caption = "Regression Estimates of the Effect of Noun and Verb Treatments on Turnout in the 2016 General Election",
                          label = "reg_pooled",
                          resizebox = ".8",
                          notes = c("The outcome variables is turnout in the 2016 general election (1=Yes, 0=No). Covariates included in the covariate adjusted specification include age, age squared divided by 100, gender, race, education, survey date, party identification, ideology, past turnout in the 2016 primary and presidential primary elections, and state fixed effects.")
)


# Save table

cat(table3_tex, file = "Table_3.tex", sep="\n")

