rm(list=ls(all=TRUE))

library(tidyverse)
library(rio)
library(estimatr)
library(stargazer)
library(xtable)

# set working directory
# setwd("~/Dropbox/Yale/VoterVoting/Shared_2016VoterVoting/BPP_replication/")

## Add line spacing at end of selected rows in tex table
add_table_space <- function(texinput, add_space_at) {
  for(i in add_space_at) {
    texinput[i] <- gsub("\\\\ ", "\\\\ & & & & & & \\\\", texinput[i], fixed=TRUE)
  }
  return(texinput)
}

## Make longtable
make_longtable_balance <- function(texinput, caption, label, cap_short) {
  
  top <- c("\\begin{center}\\small",
           "\\begin{longtable}{lrrrrrr}",
           paste0("\\caption[",cap_short,"]{",caption,"}"),
           paste0("\\label{",label,"}  \\\\"),
           "\\hline ",
           " & \\multicolumn{2}{c}{Placebo} & \\multicolumn{2}{c}{Noun} & \\multicolumn{2}{c}{Verb}\\\\",
           "Variable & N & (\\%) & N & (\\%) & N & (\\%) \\\\ ",
           "\\hline \\\\[-1.8ex] ",
           "\\endfirsthead",
           "",
           paste0("\\multicolumn{7}{c}{{\\footnotesize \\tablename\\ \\thetable{}: ",caption," (continued)}} \\\\[.5em]"),
           "\\hline ",
           " & \\multicolumn{2}{c}{Placebo} & \\multicolumn{2}{c}{Noun} & \\multicolumn{2}{c}{Verb}\\\\",
           " & N & (\\%) & N & (\\%) & N & (\\%) \\\\ ",
           "\\hline \\\\[-1.8ex] ",
           "\\endhead",
           "",
           "\\hline \\multicolumn{7}{r}{(continued)} \\\\",
           "\\endfoot",
           "",
           "\\hline \\hline",
           "\\endlastfoot")
  
  bottom <- c("\\end{longtable}",
              "\\end{center}")
  
  x <- c(top, texinput, bottom)
  return(x)
  
}

## Make three part table using output from stargazer (float=FALSE)
make3ptable <- function(texinput, caption, label, resizebox, notes) {
  out <- c("\\begin{table}[!ht]",
           "\\centering",
           paste0("\\caption{",caption,"}"),
           paste0("\\label{",label,"}"),
           paste0("\\resizebox{",resizebox,"\\textwidth}{!}{"),
           "\\begin{threeparttable}",
           texinput,
           "\\begin{tablenotes}",
           "\\item $^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01, two-tailed t-tests unless otherwise specified.",
           paste0("\\item ", notes),
           "\\end{tablenotes}",
           "\\end{threeparttable}",
           "}",
           "\\end{table}"
  )
  return(out)
}

#----------------------------------------#
# read in data
#----------------------------------------#

d <- import("data.csv")

#----------------------------------------#
# Make treatment variable a factor
#----------------------------------------#

d$treat <- factor(d$treat, levels = c("Placebo", "Noun", "Verb"))

#----------------------------------------#
# create variable denoting ex ante
#  competitiveness of state
#----------------------------------------#

table(d$state, exclude=NULL)

d$competitive <- rep(NA, nrow(d))
d$competitive <- with(d, ifelse(state %in% c("Michigan", "Ohio", "Pennsylvania"), "High", competitive))
d$competitive <- with(d, ifelse(state %in% c("California", "Connecticut", "New York", "New Jersey"), "Low", competitive))

with(d, table(state, competitive, exclude=NULL))


#----------------------------------------#
# Balance Tables
#----------------------------------------#

con_vars <- c("age", "female")

cat_vars <- c("day", "female", "vote_16p", "vote_16pp", "race", "educ", "pid7", "ideo5", "state", "marstat", "employ", "faminc", "religpew", "pew_bornagain", "pew_churatd", "competitive")
cat_vars_labels <- c("Election Day (1=Nov 8, 0=Nov 7)", 
                     "Female (1=Yes)",
                     "Voted in 2016 primary (1=Yes)",
                     "Voted in 2016 presidential primary (1=Yes)",
                     "Race/Ethnicity", "Highest Education", "Party ID", "Ideology", "State", "Marital Status", 
                     "Employment Status", "Family Income", "Religion (Pew)", "Born Again (Pew)", "Religiosity (Pew)", "State Electoral Competitiveness")

sum_cat <- NULL
for(i in 1:length(cat_vars)){
  d2 <- d[,c("treat", cat_vars[i])]
  count_temp <- table(d2[[cat_vars[i]]], d2[["treat"]])
  prop_temp <- round(prop.table(count_temp, margin = 2) * 100, 2)
  
  count_temp <- as.matrix(count_temp)
  prop_temp <- as.matrix(prop_temp)
  
  out_temp <- NULL
  for(j in 1:ncol(count_temp)) {
    out_temp[[j]] <- cbind(count_temp[,j],
                           paste0("(", sprintf("%.02f", prop_temp[,j]) , ")"))
  }
  
  out_temp <- do.call(cbind, out_temp)
  colnames(out_temp) <- c("Placebo N", "Placebo Pct",
                          "Noun N", "Noun Pct",
                          "Verb N", "Verb Pct")
  
  rownames(out_temp) <- paste0(cat_vars_labels[i], " == ", rownames(out_temp))
  sum_cat[[i]] <- out_temp
}

sum_cat <- do.call(rbind, sum_cat)
sum_cat


sum_con <- d[,c("treat", con_vars)] %>%
  group_by(treat) %>%
  summarise_all(funs(mean, sd, length)) %>%
  gather(key, value, -treat) %>%
  mutate(param = unlist(lapply(strsplit(key, "_", fixed=TRUE), function(J) J[length(J)])),
         key = gsub("_mean", "", key, fixed=TRUE),
         key = gsub("_sd", "", key, fixed=TRUE),
         key = gsub("_length", "", key, fixed=TRUE),
         key = ifelse(key == "age", "Age", key),
         new_key = paste(treat, param)) %>%
  select(-treat, -param) %>%
  spread(new_key, value)

sum_con <- as.data.frame(sum_con)
names(sum_con)[1] <- "Variable"
sum_con <- sum_con[,c(1,6,7,5,3,4,2,9,10,8)]
for(i in c(2,3,5,6,8,9)) sum_con[,i] <- sprintf("%.02f", round(sum_con[,i], 2))
for(i in c(3,6,9)) sum_con[,i] <- paste0("(", sum_con[,i] ,")")
for(i in c(4,7,10)) sum_con[,i] <- paste0("[", sum_con[,i], "]")
sum_con <- as.matrix(sum_con) # convert back to matrix to export with stargazer
sum_con <- sum_con[sum_con[,1] == "Age",] # only keep age


# TABLE S2

sum_cat <- stargazer(sum_cat)

sum_cat <- add_table_space(texinput = sum_cat, 
                           add_space_at = c(13, 15, 17, 19, 27, 33, 41, 47, 54, 60, 69, 87, 99, 101, 108))


sum_cat <- make_longtable_balance(texinput = sum_cat[12:110],
                                  caption = "Balance Table: Categorical Pre-Treatment Covariates, by Treatment Arm",
                                  label = "balance_cat",
                                  cap_short = "Balance Table: Categorical Pre-Treatment Covariates, by Treatment Arm")
cat(sum_cat, file="tableS2.tex", sep="\n")

# TABLE S1

sum_con <- stargazer(sum_con,
                     title = "Balance Table: Continuous Pre-Treatment Covariates, by Treatment Arm",
                     label = "balance_con")

sum_con[6] <- "  \\label{balance_con} \\resizebox{.8\\textwidth}{!}{ "
sum_con[7] <- "\\begin{tabular}{@{\\extracolsep{5pt}} lccc|ccc|ccc} " 
sum_con[10] <- c("& \\multicolumn{3}{c}{Placebo} & \\multicolumn{3}{c}{Noun} & \\multicolumn{3}{c}{Verb} \\\\ Variable & Mean & (SD) & [N] &  Mean & (SD) & [N]  &  Mean & (SD) & [N]  \\\\")
sum_con[13] <- "\\hline\\hline \\\\[-1.8ex] "
sum_con[14] <- "\\end{tabular} }"

cat(sum_con, file="tableS1.tex", sep="\n")

